@@ -31,6 +31,9 @@ G_BEGIN_DECLS
 _OSTREE_PUBLIC
 GType ostree_sepolicy_get_type (void);
 
+_OSTREE_PUBLIC
+void ostree_sepolicy_set_null_log (void);
+
 _OSTREE_PUBLIC
 OstreeSePolicy *ostree_sepolicy_new (GFile *path, GCancellable *cancellable, GError **error);
 
@@ -77,7 +80,4 @@ void ostree_sepolicy_fscreatecon_cleanup (void **unused);
 #define ostree_cleanup_sepolicy_fscreatecon \
   __attribute__ ((cleanup (ostree_sepolicy_fscreatecon_cleanup)))
 
-_OSTREE_PUBLIC
-gboolean ostree_sepolicy_host_enabled (OstreeSePolicy *self);
-
 G_END_DECLS
